@@ -9,36 +9,26 @@ pub fn get_args(version: &str) -> ArgMatches {
         .subcommand(
             App::new("convert")
                 .about("Converts sequence formats")
-                .arg(
-                    Arg::with_name("input")
-                        .short("i")
-                        .long("input")
-                        .help("Convert a fasta file")
-                        .takes_value(true)
-                        .required_unless("dir")
-                        .conflicts_with_all(&["dir", "wildcard"])
-                        .value_name("PATH"),
-                )
                 .arg(
                     Arg::with_name("dir")
                         .short("d")
                         .long("dir")
-                        .help("Convert multiple fasta files inside a dir")
+                        .help("Input a directory")
                         .takes_value(true)
                         .required_unless("input")
-                        .conflicts_with_all(&["input", "wildcard"])
+                        .conflicts_with("input")
                         .value_name("PATH"),
                 )
                 .arg(
-                    Arg::with_name("wildcard")
-                        .short("c")
-                        .long("wcard")
-                        .help("Convert multiple fasta files using wildcard as an input")
+                    Arg::with_name("input")
+                        .short("i")
+                        .long("input")
+                        .help("Input path with wildcard support")
                         .takes_value(true)
                         .multiple(true)
-                        .required_unless("input")
-                        .conflicts_with_all(&["input", "dir"])
-                        .value_name("WILDCARD"),
+                        .required_unless("dir")
+                        .conflicts_with("dir")
+                        .value_name("INPUT-PATH"),
                 )
                 .arg(
                     Arg::with_name("output")
@@ -46,7 +36,8 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .long("output")
                         .help("Sets target directory or use a costume file name for a single input")
                         .takes_value(true)
-                        .required_unless("input")
+                        .required(true)
+                        .default_value("SEGUL-Convert")
                         .value_name("STRING"),
                 )
                 .arg(
@@ -108,19 +99,19 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .long("dir")
                         .help("Inputs alignment dir")
                         .takes_value(true)
-                        .required_unless("wildcard")
+                        .required_unless("input")
                         .value_name("PATH"),
                 )
                 .arg(
-                    Arg::with_name("wildcard")
-                        .short("c")
-                        .long("wcard")
-                        .help("Uses wildcard as an input")
+                    Arg::with_name("input")
+                        .short("i")
+                        .long("input")
+                        .help("Input path with wildcard support")
                         .takes_value(true)
                         .multiple(true)
-                        .required_unless("input")
-                        .conflicts_with_all(&["input", "dir"])
-                        .value_name("WILDCARD"),
+                        .required_unless("dir")
+                        .conflicts_with("dir")
+                        .value_name("INPUT-PATH"),
                 )
                 .arg(
                     Arg::with_name("input-format")
@@ -156,7 +147,7 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .help("Uses a costume output directory")
                         .takes_value(true)
                         .required(true)
-                        .default_value("concat")
+                        .default_value("SEGUL-Concat")
                         .value_name("STRING"),
                 )
                 .arg(
@@ -209,19 +200,19 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .long("dir")
                         .help("Inputs a path to alignment dir")
                         .takes_value(true)
-                        .required(true)
+                        .required_unless("input")
                         .value_name("PATH"),
                 )
                 .arg(
-                    Arg::with_name("wildcard")
-                        .short("c")
-                        .long("wcard")
-                        .help("Uses wildcard as an input")
+                    Arg::with_name("input")
+                        .short("i")
+                        .long("input")
+                        .help("Input path with wildcard support")
                         .takes_value(true)
                         .multiple(true)
-                        .required_unless("input")
+                        .required_unless("dir")
                         .conflicts_with("dir")
-                        .value_name("WILDCARD"),
+                        .value_name("INPUT-PATH"),
                 )
                 .arg(
                     Arg::with_name("input-format")
@@ -369,15 +360,15 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .value_name("PATH"),
                 )
                 .arg(
-                    Arg::with_name("wildcard")
-                        .short("c")
-                        .long("wcard")
-                        .help("Uses wildcard as an input")
+                    Arg::with_name("input")
+                        .short("i")
+                        .long("input")
+                        .help("Input path with wildcard support")
                         .takes_value(true)
                         .multiple(true)
                         .required_unless("input")
                         .conflicts_with("dir")
-                        .value_name("WILDCARD"),
+                        .value_name("INPUT-PATH"),
                 )
                 .arg(
                     Arg::with_name("input-format")
@@ -414,6 +405,13 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .required(true)
                         .default_value("id")
                         .value_name("STRING"),
+                )
+                .arg(
+                    Arg::with_name("map")
+                        .short("m")
+                        .long("map")
+                        .help("Map ID across all alignments")
+                        .takes_value(false),
                 ),
         )
         .subcommand(
@@ -428,15 +426,15 @@ pub fn get_args(version: &str) -> ArgMatches {
                     .value_name("PATH"),
                 )
                 .arg(
-                    Arg::with_name("wildcard")
-                            .short("c")
-                            .long("wcard")
-                            .help("Uses wildcard as an input")
+                    Arg::with_name("input")
+                            .short("i")
+                            .long("input")
+                            .help("Input path with wildcard support")
                             .takes_value(true)
                             .multiple(true)
                             .required_unless("input")
                             .conflicts_with_all(&["input", "dir"])
-                            .value_name("WILDCARD"),
+                            .value_name("INPUT-PATH"),
                 )
                 .arg(
                     Arg::with_name("input-format")
@@ -461,7 +459,7 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .help("Uses a costume output filename")
                         .takes_value(true)
                         .required(true)
-                        .default_value("SEGUL-rename")
+                        .default_value("SEGUL-Rename")
                         .value_name("STRING"),
                 )
                 .arg(
@@ -511,35 +509,25 @@ pub fn get_args(version: &str) -> ArgMatches {
         .subcommand(
             App::new("summary")
                 .about("Gets alignment summary stats")
-                .arg(
-                    Arg::with_name("input")
-                        .short("i")
-                        .long("input")
-                        .help("Gets summary from a file")
-                        .takes_value(true)
-                        .required_unless("dir")
-                        .conflicts_with_all(&["dir", "wildcard"])
-                        .value_name("PATH"),
-                )
                 .arg(
                     Arg::with_name("dir")
                         .short("d")
                         .long("dir")
                         .help("Gets summary from alignment files")
                         .takes_value(true)
-                        .conflicts_with_all(&["input", "wildcard"])
+                        .conflicts_with("input")
                         .value_name("PATH"),
                 )
                 .arg(
-                    Arg::with_name("wildcard")
-                        .short("c")
-                        .long("wcard")
-                        .help("Uses wildcard as an input")
+                    Arg::with_name("input")
+                        .short("i")
+                        .long("input")
+                        .help("Input path with wildcard support")
                         .takes_value(true)
                         .multiple(true)
-                        .required_unless("input")
-                        .conflicts_with_all(&["input", "dir"])
-                        .value_name("WILDCARD"),
+                        .required_unless("dir")
+                        .conflicts_with("dir")
+                        .value_name("INPUT-PATH"),
                 )
                 .arg(
                     Arg::with_name("input-format")
@@ -564,7 +552,7 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .help("Uses a costume output filename")
                         .takes_value(true)
                         .required(true)
-                        .default_value("SEGUL-stats")
+                        .default_value("SEGUL-Stats")
                         .value_name("STRING"),
                 )
                 .arg(
@@ -596,19 +584,19 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .long("dir")
                         .help("Inputs a directory path to alignments")
                         .takes_value(true)
-                        .conflicts_with("wildcard")
+                        .conflicts_with("input")
                         .value_name("PATH"),
                 )
                 .arg(
-                    Arg::with_name("wildcard")
-                        .short("c")
-                        .long("wcard")
-                        .help("Uses wildcard as an input")
+                    Arg::with_name("input")
+                        .short("i")
+                        .long("input")
+                        .help("Input path with wildcard support")
                         .takes_value(true)
                         .multiple(true)
-                        .required_unless("input")
+                        .required_unless("dir")
                         .conflicts_with("dir")
-                        .value_name("WILDCARD"),
+                        .value_name("INPUT-PATH"),
                 )
                 .arg(
                     Arg::with_name("input-format")
@@ -660,7 +648,7 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .help("Specifies a directory name")
                         .takes_value(true)
                         .required(true)
-                        .default_value("SEGUL-extract")
+                        .default_value("SEGUL-Extract")
                         .value_name("STRING"),
                 )
                 .arg(
@@ -700,19 +688,19 @@ pub fn get_args(version: &str) -> ArgMatches {
                         .long("dir")
                         .help("Inputs a directory path to alignments")
                         .takes_value(true)
-                        .conflicts_with("wildcard")
+                        .conflicts_with("input")
                         .value_name("PATH"),
                 )
                 .arg(
-                    Arg::with_name("wildcard")
-                        .short("c")
-                        .long("wcard")
-                        .help("Uses wildcard as an input")
+                    Arg::with_name("input")
+                        .short("i")
+                        .long("input")
+                        .help("Input path with wildcard support")
                         .takes_value(true)
                         .multiple(true)
                         .required_unless_one(&["dir", "show-tables"])
                         .conflicts_with("dir")
-                        .value_name("WILDCARD"),
+                        .value_name("INPUT-PATH"),
                 )
                 .arg(
                     Arg::with_name("input-format")
