@@ -1,17 +1,18 @@
-use std::path::PathBuf;
+use std::path::{Path, PathBuf};
 
 use ansi_term::Colour::Yellow;
 use clap::ArgMatches;
 
-use crate::cli::*;
+use crate::cli::{ConcatCli, InputCli, InputPrint, OutputCli};
 use crate::core::filter::{Params, SeqFilter};
-use crate::helper::filenames;
-use crate::helper::types::{DataType, InputFmt, OutputFmt};
+use crate::helper::finder::IDs;
+use crate::helper::types::{DataType, InputFmt, OutputFmt, PartitionFmt};
+use crate::helper::{filenames, utils};
 
 impl InputCli for FilterParser<'_> {}
 impl InputPrint for FilterParser<'_> {}
 impl OutputCli for FilterParser<'_> {}
-impl ConcatCLi for FilterParser<'_> {}
+impl ConcatCli for FilterParser<'_> {}
 
 pub(in crate::cli) struct FilterParser<'a> {
     matches: &'a ArgMatches<'a>,
@@ -44,14 +45,14 @@ impl<'a> FilterParser<'a> {
         self.input_fmt = self.parse_input_fmt(self.matches);
         self.datatype = self.parse_datatype(self.matches);
         let task_desc = "Alignment filtering";
-        self.files = if self.is_input_dir() {
+        self.files = if self.matches.is_present("dir") {
             let dir = self.parse_dir_input(self.matches);
             self.input_dir = Some(PathBuf::from(dir));
             self.get_files(dir, &self.input_fmt)
         } else {
-            self.parse_input_wcard(self.matches)
+            self.parse_input(self.matches)
         };
-        self.print_input_multi(
+        self.print_input(
             &self.input_dir,
             task_desc,
             self.files.len(),
@@ -271,10 +272,6 @@ impl<'a> FilterParser<'a> {
     fn is_npercent(&mut self) -> bool {
         self.matches.is_present("npercent")
     }
-
-    fn is_input_dir(&self) -> bool {
-        self.matches.is_present("dir")
-    }
 }
 
 #[cfg(test)]
