@@ -32,10 +32,7 @@ use crate::cli::rename::RenameParser;
 use crate::cli::summarize::SummaryParser;
 use crate::cli::translate::TranslateParser;
 
-use crate::check_output_path;
-use crate::core::msa;
-use crate::core::summarize::SeqStats;
-use crate::helper::finder::{Files, IDs};
+use crate::helper::finder::Files;
 use crate::helper::types::{DataType, InputFmt, OutputFmt, PartitionFmt};
 use crate::helper::utils;
 
@@ -87,29 +84,36 @@ fn setup_logger() -> Result<()> {
     Ok(())
 }
 
-enum InputType {
-    File,
-    Dir,
-    Wildcard,
+macro_rules! check_output_path {
+    ($type: ident, $execution: ident, $path: ident, $prompt: expr, $err_msg: expr) => {
+        if $path.$type() {
+            let selection = Confirm::with_theme(&ColorfulTheme::default())
+                .with_prompt($prompt)
+                .interact();
+            match selection {
+                Ok(yes) => {
+                    if yes {
+                        fs::$execution($path).expect($err_msg);
+                        println!();
+                    } else {
+                        std::process::abort();
+                    }
+                }
+                Err(err) => panic!("Failed parsing user input: {}", err),
+            }
+        }
+    };
 }
 
 trait InputCli {
-    fn parse_file_input<'a>(&self, matches: &'a ArgMatches) -> &'a Path {
-        Path::new(
-            matches
-                .value_of("input")
-                .expect("Failed parsing an input value"),
-        )
-    }
-
     fn parse_dir_input<'a>(&self, matches: &'a ArgMatches) -> &'a Path {
         Path::new(matches.value_of("dir").expect("Failed parsing a dir value"))
     }
 
-    fn parse_input_wcard(&self, matches: &ArgMatches) -> Vec<PathBuf> {
+    fn parse_input(&self, matches: &ArgMatches) -> Vec<PathBuf> {
         let inputs = matches
-            .values_of("wildcard")
-            .expect("Failed parsing wildcard values")
+            .values_of("input")
+            .expect("Failed parsing input values")
             .map(PathBuf::from)
             .collect::<Vec<PathBuf>>();
         if cfg!(windows) {
@@ -137,16 +141,6 @@ trait InputCli {
         Files::new(dir, input_fmt).get_files()
     }
 
-    fn parse_input_type(&self, matches: &ArgMatches) -> InputType {
-        if matches.is_present("input") {
-            InputType::File
-        } else if matches.is_present("dir") {
-            InputType::Dir
-        } else {
-            InputType::Wildcard
-        }
-    }
-
     fn parse_input_fmt(&self, matches: &ArgMatches) -> InputFmt {
         let input_fmt = matches
             .value_of("input-format")
@@ -174,20 +168,7 @@ trait InputCli {
 }
 
 trait InputPrint {
-    fn print_input_file(
-        &self,
-        input: &Path,
-        task_desc: &str,
-        input_fmt: &InputFmt,
-        datatype: &DataType,
-    ) {
-        log::info!("{:18}: {}", "Input", &input.display());
-        self.print_input_fmt(input_fmt);
-        self.print_datatype(datatype);
-        log::info!("{:18}: {}\n", "Task", task_desc);
-    }
-
-    fn print_input_multi<P: AsRef<Path>>(
+    fn print_input<P: AsRef<Path>>(
         &self,
         input: &Option<P>,
         task_desc: &str,
@@ -198,7 +179,7 @@ trait InputPrint {
         if let Some(input) = input {
             log::info!("{:18}: {}", "Input dir", &input.as_ref().display());
         } else {
-            log::info!("{:18}: {}", "Input dir", "WILDCARD");
+            log::info!("{:18}: {}", "Input", "STDIN");
         }
         log::info!("{:18}: {}", "File counts", utils::fmt_num(&fcounts));
         self.print_input_fmt(input_fmt);
@@ -248,27 +229,29 @@ trait OutputCli {
     }
 
     fn check_output_file_exist(&self, path: &Path) {
+        let error_msg = format!("Output file already exists: {}", path.display());
         check_output_path!(
             is_file,
             remove_file,
             path,
-            "The same output file exists! Remove it?",
+            error_msg,
             "Failed removing files"
         );
     }
 
     fn check_output_dir_exist(&self, path: &Path) {
+        let error_msg = format!("Output dir already exists: {}", path.display());
         check_output_path!(
             is_dir,
             remove_dir_all,
             path,
-            "The same output directory exists! Remove it?",
+            error_msg,
             "Failed removing a directory"
         )
     }
 }
 
-trait ConcatCLi {
+trait ConcatCli {
     fn parse_prefix(&self, matches: &ArgMatches, dir: &Path) -> PathBuf {
         if matches.is_present("prefix") {
             let prefix = matches
@@ -323,25 +306,3 @@ trait ConcatCLi {
         }
     }
 }
-
-#[macro_export]
-macro_rules! check_output_path {
-    ($type: ident, $execution: ident, $path: ident, $prompt: stmt, $err_msg: stmt) => {
-        if $path.$type() {
-            let selection = Confirm::with_theme(&ColorfulTheme::default())
-                .with_prompt(stringify!($prompt))
-                .interact();
-            match selection {
-                Ok(yes) => {
-                    if yes {
-                        fs::$execution($path).expect(stringify!($err_msg));
-                        println!();
-                    } else {
-                        std::process::abort();
-                    }
-                }
-                Err(err) => panic!("Failed parsing user input: {}", err),
-            }
-        }
-    };
-}
